@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import print_function
+from __future__ import absolute_import
 
 import os
 import sys
@@ -16,8 +17,9 @@ from tables import Atom, ClosedNodeError, NoSuchNodeError
 from tables.utils import byteorders
 from tables.tests import common
 from tables.tests.common import allequal
-from tables.tests.common import unittest
+from tables.tests.common import unittest, test_filename
 from tables.tests.common import PyTablesTestCase as TestCase
+from six.moves import range
 
 
 warnings.resetwarnings()
@@ -2394,7 +2396,7 @@ class CopyNativeHDF5MDAtom(TestCase):
 
     def setUp(self):
         super(CopyNativeHDF5MDAtom, self).setUp()
-        filename = self._testFilename("array_mdatom.h5")
+        filename = test_filename("array_mdatom.h5")
         self.h5file = tables.open_file(filename, "r")
         self.arr = self.h5file.root.arr
         self.copy = tempfile.mktemp(".h5")
@@ -2454,8 +2456,8 @@ class BroadcastTest(common.TempFileMixin, TestCase):
 
         dtype = numpy.dtype((numpy.int, element_shape))
         atom = Atom.from_dtype(dtype)
-        h5arr = self.h5file.create_carray(self.h5file.root, 'array',
-                                          atom, array_shape)
+        h5arr = self.h5file.create_array(self.h5file.root, 'array',
+                                          atom=atom, shape=array_shape)
 
         size = numpy.prod(element_shape)
         nparr = numpy.arange(size).reshape(element_shape)
